@@ -36,8 +36,8 @@
 #'   }
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -101,7 +101,7 @@ BlackBoostModel <- function(
         )
       }
       mboost::blackboost(
-        formula, data = as.data.frame(formula, data), weights = weights,
+        formula, data = as.data.frame(formula, data = data), weights = weights,
         na.action = na.pass, family = family,
         control = mboost::boost_control(
           mstop = mstop, nu = nu, risk = risk, stopintern = stopintern,
