@@ -29,8 +29,8 @@
 #'   }
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -97,9 +97,10 @@ GAMBoostModel <- function(
         )
       }
       mboost::gamboost(
-        formula, data = as.data.frame(formula, data), na.action = na.pass,
-        weights = weights, family = family, baselearner = baselearner,
-        dfbase = dfbase, control = mboost::boost_control(...)
+        formula, data = as.data.frame(formula, data = data),
+        na.action = na.pass, weights = weights, family = family,
+        baselearner = baselearner, dfbase = dfbase,
+        control = mboost::boost_control(...)
       )
     },
 
