@@ -50,7 +50,7 @@ PLSModel <- function(ncomp = 1, scale = FALSE) {
 
     fit = function(formula, data, weights, ...) {
       y <- response(data)
-      data <- as.data.frame(formula, data)
+      data <- as.data.frame(formula, data = data)
       if (is.factor(y)) {
         mm <- model.matrix(~ y - 1)
         colnames(mm) <- levels(y)
