@@ -49,8 +49,8 @@
 #'   }
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' In calls to \code{\link{varimp}} for \code{RFSRCModel}, argument
 #' \code{type} may be specified as \code{"permute"} (default) for permutation of
@@ -120,7 +120,7 @@ RFSRCModel <- function(
 
     fit = function(formula, data, weights, ...) {
       y <- response(data)
-      data <- as.data.frame(formula, data)
+      data <- as.data.frame(formula, data = data)
       family <- switch_class(y,
         "matrix" = {
           colnames(y) <- make_names_len(ncol(y), "y")
