@@ -14,8 +14,8 @@
 #'   \item{Response types:}{\code{Surv}}
 #' }
 #'
-#' Default values and further model details can be found in the source links
-#' below.
+#' Default argument values and further model details can be found in the source
+#' See Also links below.
 #'
 #' @return \code{MLModel} class object.
 #'
@@ -44,7 +44,7 @@ SurvRegModel <- function(
 
     fit = function(formula, data, weights, dist, scale, parms = NULL, ...) {
       rms::psm(
-        formula, data = as.data.frame(formula, data), weights = weights,
+        formula, data = as.data.frame(formula, data = data), weights = weights,
         na.action = na.pass, dist = dist, scale = scale, parms = parms,
         control = survival::survreg.control(...)
       )
@@ -128,7 +128,7 @@ SurvRegStepAICModel <- function(
       formula, data, weights, dist, scale, parms = NULL, ...,
       direction, scope = list(), k, trace, steps
     ) {
-      data <- as.data.frame(formula, data)
+      data <- as.data.frame(formula, data = data)
       stepargs <- stepAIC_args(formula, direction, scope)
       MASS::stepAIC(
         rms::psm(
